==> scanbot_sdk-1.1.0.tar.gz: ios/Classes/Extensions/SDK/Scanner Configuration/SBSDKUIDocumentScannerBehaviorConfiguration.swift <==
//
//  SBSDKUIDocumentScannerBehaviorConfiguration.swift
//  Runner
//
//  Created by Zhenya Knizhnik on 22.08.19.
//  Copyright © 2019 The Chromium Authors. All rights reserved.
//

import Foundation
import ScanbotSDK

extension SBSDKUIDocumentScannerBehaviorConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()

        if let isAutoSnappingEnabled = dictionary["autoSnappingEnabled"] as? Bool {
            self.isAutoSnappingEnabled = isAutoSnappingEnabled
        }
        
        if let isMultiPageEnabled = dictionary["multiPageEnabled"] as? Bool {
            self.isMultiPageEnabled = isMultiPageEnabled
        }
        
        if let isFlashEnabled = dictionary["flashEnabled"] as? Bool {
            self.isFlashEnabled = isFlashEnabled
        }
        
        if let ignoreBadAspectRatio = dictionary["ignoreBadAspectRatio"] as? Bool {
            self.ignoreBadAspectRatio = ignoreBadAspectRatio
        }
        
        if let autoSnappingSensitivity = dictionary["autoSnappingSensitivity"] as? CGFloat {
            self.autoSnappingSensitivity = autoSnappingSensitivity
        }
        
        if let acceptedSizeScore = dictionary["acceptedSizeScore"] as? Double {
            self.acceptedSizeScore = acceptedSizeScore
        }
        
        if let acceptedAngleScore = dictionary["acceptedAngleScore"] as? Double {
            self.acceptedAngleScore = acceptedAngleScore
        }
        
        if let dictionary = dictionary["documentImageSizeLimit"] as? [String: Any] {
            let documentImageSizeLimit = CGSize(from: dictionary)
            self.documentImageSizeLimit = documentImageSizeLimit
        }
        
        if let string = dictionary["cameraPreviewMode"] as? String {
            let cameraPreviewMode = SBSDKUIVideoContentMode(from: string)
            self.cameraPreviewMode = cameraPreviewMode
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let orientationLockMode = SBSDKOrientationLock(from: string)
            self.orientationLockMode = orientationLockMode
        }
        
        if let maxNumberOfPages = dictionary["maxNumberOfPages"] as? Int {
            self.maxNumberOfPages = NSNumber(value: maxNumberOfPages)
        }
    }
}

==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Extensions/SDK/Scanner Configuration/SBSDKUIDocumentScannerBehaviorConfiguration.swift <==
//
//  SBSDKUIDocumentScannerBehaviorConfiguration.swift
//  Runner
//
//  Created by Zhenya Knizhnik on 22.08.19.
//  Copyright © 2019 The Chromium Authors. All rights reserved.
//

import Foundation
import ScanbotSDK

extension SBSDKUIDocumentScannerBehaviorConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()

        if let isAutoSnappingEnabled = dictionary["autoSnappingEnabled"] as? Bool {
            self.isAutoSnappingEnabled = isAutoSnappingEnabled
        }
        
        if let isMultiPageEnabled = dictionary["multiPageEnabled"] as? Bool {
            self.isMultiPageEnabled = isMultiPageEnabled
        }
        
        if let isFlashEnabled = dictionary["flashEnabled"] as? Bool {
            self.isFlashEnabled = isFlashEnabled
        }
        
        if let ignoreBadAspectRatio = dictionary["ignoreBadAspectRatio"] as? Bool {
            self.ignoreBadAspectRatio = ignoreBadAspectRatio
        }
        
        if let autoSnappingSensitivity = dictionary["autoSnappingSensitivity"] as? CGFloat {
            self.autoSnappingSensitivity = autoSnappingSensitivity
        }
        
        if let acceptedSizeScore = dictionary["acceptedSizeScore"] as? Double {
            self.acceptedSizeScore = acceptedSizeScore
        }
        
        if let acceptedAngleScore = dictionary["acceptedAngleScore"] as? Double {
            self.acceptedAngleScore = acceptedAngleScore
        }
        
        if let dictionary = dictionary["documentImageSizeLimit"] as? [String: Any] {
            let documentImageSizeLimit = CGSize(from: dictionary)
            self.documentImageSizeLimit = documentImageSizeLimit
        }
        
        if let string = dictionary["cameraPreviewMode"] as? String {
            let cameraPreviewMode = SBSDKVideoContentMode(from: string)
            self.cameraPreviewMode = cameraPreviewMode
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let orientationLockMode = SBSDKOrientationLock(from: string)
            self.orientationLockMode = orientationLockMode
        }
        
        if let maxNumberOfPages = dictionary["maxNumberOfPages"] as? Int {
            self.maxNumberOfPages = NSNumber(value: maxNumberOfPages)
        }
    }
}
